@@ -8,6 +8,7 @@ import click
 from .app_manager import start_app
 from .graphql import graphql
 from .run import run
+from .sql_alembic import cli as cli_sql
 
 
 @click.group()
@@ -19,3 +20,4 @@ def cli():
 cli.add_command(run)
 cli.add_command(graphql)
 cli.add_command(start_app)
+cli.add_command(cli_sql)
