@@ -7,6 +7,8 @@ from graphql.validation import NoSchemaIntrospectionCustomRule
 from strawberry.extensions import AddValidationRules, QueryDepthLimiter
 from strawberry.tools import merge_types
 
+from .config import Settings
+
 
 def Schema(
     query: list = None,
@@ -15,7 +17,7 @@ def Schema(
     max_depth: int = 4,
     introspection: bool = True,
     **kwargs
-) -> strawberry.Schema:
+) -> strawberry.Schema | None:
     """Strawberry Schema Wrapper"""
 
     query = query or []
@@ -24,17 +26,21 @@ def Schema(
 
     Query = tuple(query)
     Mutation = tuple(mutation)
-
-    # Extension
     Extensions = [
         QueryDepthLimiter(max_depth=max_depth),
     ]
     Extensions.extend(extensions)
 
+    # Apps Extensions
+    settings = Settings()
+    if len(settings.extensions) > 0:
+        Extensions.extend(settings.extensions)
+
     # Introspection
     if not introspection:
         Extensions.append(AddValidationRules([NoSchemaIntrospectionCustomRule]))
 
+    # Query & Mutation
     items = {}
     if Query:
         items["query"] = merge_types("Query", Query)
@@ -42,4 +48,6 @@ def Schema(
         items["mutation"] = merge_types("Mutation", Mutation)
 
     # Return Value
-    return strawberry.Schema(**items, extensions=Extensions, **kwargs)
+    if Query:
+        return strawberry.Schema(**items, extensions=Extensions, **kwargs)
+    return None
