@@ -58,7 +58,7 @@ class SQLBase:
     -----------------------------------------------------------------------------------------------
     # Init
     -----------------------------------------------------------------------------------------------
-    sql = SQL(SQlAlchemyORM.__table__)
+    sql = SQLBase(database_url, custom_type)
 
     -----------------------------------------------------------------------------------------------
     # Form
